==> tuia-news-center-api-0.0.44-xt4-20180627.033812-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/FriendDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/22.
 */
public class FriendDto implements Serializable{

    private Long id;

    private Long userId;

    private Long friendId;

    private String friendName;

    private String friandHead;

    private Integer friendStatus;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getFriendId() {
        return friendId;
    }

    public void setFriendId(Long friendId) {
        this.friendId = friendId;
    }

    public String getFriendName() {
        return friendName;
    }

    public void setFriendName(String friendName) {
        this.friendName = friendName == null ? null : friendName.trim();
    }

    public String getFriandHead() {
        return friandHead;
    }

    public void setFriandHead(String friandHead) {
        this.friandHead = friandHead == null ? null : friandHead.trim();
    }

    public Integer getFriendStatus() {
        return friendStatus;
    }

    public void setFriendStatus(Integer friendStatus) {
        this.friendStatus = friendStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-0.0.46-xt10-20180713.020550-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/FriendDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaotian on 2018/6/22.
 */
public class FriendDto implements Serializable{

    private Long id;

    private Long userId;

    private Long friendId;

    private String friendName;

    private String friendHead;

    private Integer friendStatus;

    private Integer steal;

    private Long ripeTime;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getRipeTime() {
        return ripeTime;
    }

    public void setRipeTime(Long ripeTime) {
        this.ripeTime = ripeTime;
    }

    public Integer getSteal() {
        return steal;
    }

    public void setSteal(Integer steal) {
        this.steal = steal;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getFriendId() {
        return friendId;
    }

    public void setFriendId(Long friendId) {
        this.friendId = friendId;
    }

    public String getFriendName() {
        return friendName;
    }

    public void setFriendName(String friendName) {
        this.friendName = friendName == null ? null : friendName.trim();
    }

    public String getFriendHead() {
        return friendHead;
    }

    public void setFriendHead(String friendHead) {
        this.friendHead = friendHead;
    }

    public Integer getFriendStatus() {
        return friendStatus;
    }

    public void setFriendStatus(Integer friendStatus) {
        this.friendStatus = friendStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
